@@ -56,7 +56,11 @@ class Command:
                     variables[key] = file.read().strip()
 
         for key, value in self.env.config['constants'].items():
+            # DEPRECATED, use CONST instead
             variables[f'const_{key}'] = value
+
+        variables['CONST'] = ConstantsWrapper(self.env.config['constants'])
+        variables['SYSTEMS'] = SystemsWrapper(self.env.systems)
         return self.value.format(**variables)
 
     def execute(self, interactive: bool = False, force: bool = False):
@@ -74,7 +78,7 @@ class Command:
             if self.env.batch_mode:
                 options += ', c: abort & continue to next (CSV processing)'
 
-            answer = input(f'[MS] Proceed? ({options})')
+            answer = input(f'[MS] Proceed? ({options})\a')
             if answer == 's':
                 return
             if answer == 'a':
@@ -103,7 +107,7 @@ class Command:
             if self.env.batch_mode:
                 err_options += ', c: abort & continue to next (CSV processing)'
 
-            err_answer = input(f'[CF] What should I do? ({err_options})')
+            err_answer = input(f'[CF] What should I do? ({err_options})\a')
             if err_answer == 'r':
                 return self.execute(interactive)
             if err_answer == 'a':
@@ -180,7 +184,7 @@ class Command:
                     )
                     answer = input(
                         '[RR] What should I do? '
-                        '(i: send SIGINT (default), t: send SIGTERM, k: send SIGKILL, p: do nothing and proceed) \n')
+                        '(i: send SIGINT (default), t: send SIGTERM, k: send SIGKILL, p: do nothing and proceed) \n\a')
 
                     if answer == 'p':
                         break
@@ -256,6 +260,22 @@ def parse_key(key) -> Tuple[str, ...]:
     return re.search(r'((.*)\?)?((.*)=)?(.*)', key).group(2, 4, 5)
 
 
+class SystemsWrapper:
+    def __init__(self, systems: dict):
+        self.systems = systems
+
+    def __getattr__(self, name):
+        return self.systems[name].replace('hostname!', '')
+
+
+class ConstantsWrapper:
+    def __init__(self, constants: dict):
+        self.constants = constants
+
+    def __getattr__(self, name):
+        return self.constants[name]
+
+
 class AbortException(Exception):
     def __init__(self, return_code: int):
         self.return_code = return_code
